Changelog
=========

0.2 (2013-11-19)
----------------

- Set custom hostname for development environment so chef search works.
- Enabled data upload (Data.fs and blobs).


0.1.1 (2013-11-19)
------------------

- Added missing files.


0.1 (2013-11-19)
----------------

- Work with development, staging and production environments.
- Check for chef roles and create missing ones from configurations.
- Bootstrap MLS systems.
- Remove MLS clients if not needed any more.
- Manage database, frontend and worker components.
- Update client buildout packages.
- Download database files for local testing.
